import java.awt.*;
import java.awt.image.*;
import java.awt.event.*;
import javax.swing.*;
import java.util.*;

/**
 * Esta clase representa al contenido que se encuentra en la ventana de juego.
 * @author Ricardo Monascal
 **/
public class PlazaHeroPanel extends JPanel implements KeyListener {

// Constantes de la clase.

	/**
	 * Color del fondo.
	 **/
	private static final Color FONDO = Color.BLACK;

	/**
	 * Frames por segundo del juego.
	 **/
	private static final int FPS = 30;

// Campos de la clase.

	/**
	 * Administra los eventos temporizados.
	 **/
	private java.util.Timer T = new java.util.Timer ();

	/**
	 * Mundo donde se desenvuelve el juego.
	 **/
	private MundoDeJuego mundo;

// Constructor de la clase.
	 
	/**
	 * Constructor de la clase.
	 **/
	public PlazaHeroPanel(Dimension medidas) {
		
		setPreferredSize(medidas);
		setBackground(FONDO);
		mundo = new MundoDeJuego (medidas.width,medidas.height-48);
		T.schedule(new Actualizador(),0,1000/FPS);
		
	}

// Funciones y mtodos de la clase.

	/**
	 * Dibuja el contenido en la ventana de juego.
	 **/
	@Override
	public void paintComponent (Graphics g) {
		
		super.paintComponent (g);
		mundo.pintar(g);
		
	}

// Implementacion de la interfaz MouseListener

	/**
	 * Especifica las acciones a realizarse cuando se ha presionado una tecla.
	 **/
	public void keyPressed (KeyEvent e) {
		
		switch (mundo.obtenerEstado()) {
			case MundoDeJuego.E_MENU:
				switch (e.getKeyCode()) {
					// Controles de canal seleccinado
					case KeyEvent.VK_UP:
						mundo.modificarSeleccionado(false);
						break;
					case KeyEvent.VK_DOWN:
						mundo.modificarSeleccionado(true);
						break;
					case KeyEvent.VK_SPACE:
						mundo.comenzarJuego();
						break;
				}
				break;
			case MundoDeJuego.E_JUEGO:
				switch (e.getKeyCode()) {
					// Controles del color de las fuentes.
					case KeyEvent.VK_1:
						mundo.asignarColorFuente(0);
						break;
					case KeyEvent.VK_2:
						mundo.asignarColorFuente(1);
						break;
					case KeyEvent.VK_3:
						mundo.asignarColorFuente(2);
						break;
					case KeyEvent.VK_4:
						mundo.asignarColorFuente(3);
						break;
					// Controles de canal seleccinado
					case KeyEvent.VK_UP:
						mundo.modificarSeleccionado(false);
						break;
					case KeyEvent.VK_DOWN:
						mundo.modificarSeleccionado(true);
						break;
					case KeyEvent.VK_SPACE:
						mundo.pausar();
						break;
				}
				break;
			case MundoDeJuego.E_PAUSA:
				switch (e.getKeyCode()) {
					case KeyEvent.VK_SPACE:
						mundo.pausar();
						break;
				}
				break;
		}
		
	}

	/**
	 * Especifica las acciones a realizarse cuando se ha liberado una tecla.
	 **/
	public void keyReleased (KeyEvent e) {
		
		// No hace nada.
		
	}

	/**
	 * Especifica las acciones a realizarse cuando se ha tipeado una tecla.
	 **/
	public void keyTyped (KeyEvent e) {
		
		// No hace nada.
		
	}

// Clases privadas

	/**
	 * Esta clase es una tarea temporizada para actualizar el estado del juego.
	 **/
	private class Actualizador extends TimerTask {
	
		/**
		 * Dice que debe hacerse cada vez que el temporizador lo indique.
		 **/
		public void run () {
			
			mundo.actualizar();
			repaint();
			
		}
	
	}

}